@@ -15,13 +15,13 @@ from json import loads, dumps
 class ControllerAPIModule(ControllerModule):
     # TODO: Move the collection version check into controller_module.py
     # This gets set by the make process so whatever is in here is irrelevant
-    _COLLECTION_VERSION = "4.0.0"
+    _COLLECTION_VERSION = "4.0.1"
     _COLLECTION_TYPE = "controller"
     # This maps the collections type (awx/tower) to the values returned by the API
     # Those values can be found in awx/api/generics.py line 204
     collection_to_version = {
         'awx': 'AWX',
-        'controller': 'Red Hat Automation Platform Controller',
+        'controller': 'Red Hat Ansible Automation Platform',
     }
     session = None
     IDENTITY_FIELDS = {'users': 'username', 'workflow_job_template_nodes': 'identifier', 'instances': 'hostname'}
